==> digikam-3.0.0.tar.bz2: digikam-3.0.0/extra/kipi-plugins/flashexport/kipiplugin_flashexport.desktop.cmake <==
[Desktop Entry]
UntranslatedGenericName=Flash Export
Name=Flash Export
Name[ast]=Esportar flash
Name[bg]=Изнасяне във Flash
Name[bs]=Flash izvoz
Name[ca]=Exportador a Flash
Name[ca@valencia]=Exportador a Flash
Name[cs]=Flash Export
Name[da]=Flash-eksport
Name[de]=Flash-Export
Name[el]=Εξαγωγή Flash
Name[en_GB]=Flash Export
Name[es]=Exportar a Flash
Name[et]=Flashi eksport
Name[eu]=Flash-era esportatzea
Name[fi]=Flash-vienti
Name[fr]=Exportation Flash
Name[ga]=Easpórtáil Flash
Name[gl]=Exportación a Flash
Name[hu]=Flash exportálás
Name[is]=Flash útflutningur
Name[it]=Esportazione a Flash
Name[ja]=Flash Export
Name[km]=កម្មវិធី​នាំចេញ Flash
Name[lv]=Flash eksportētājs
Name[nb]=Flash-eksport
Name[nds]=Flash-Exporteren
Name[nl]=Flash-export
Name[pa]=ਫਲੈਸ਼ ਐਕਸਪੋਰਟ
Name[pl]=Eksport Flash
Name[pt]=Exportação para Flash
Name[pt_BR]=Exportar para Flash
Name[ro]=Export Flash
Name[ru]=Экспорт во Flash
Name[sk]=Flash export
Name[sl]=Izvoz v Flash
Name[sq]=Flash Export
Name[sv]=Export till Flash
Name[th]=ส่งออกเป็นแฟ้ม Flash
Name[tr]=Flash olarak Dışarı Aktar
Name[ug]=Flash Export
Name[uk]=Експорт у Flash
Name[x-test]=xxFlash Exportxx
Name[zh_CN]=Flash 导出
Name[zh_TW]=Flash 匯出
Comment=A tool to export images to Flash
Comment[ast]=Una ferramienta pa esportar imáxenes a Flash
Comment[bg]=Инструмент за изнасяне на изображения във Flash
Comment[bs]=Alat za izvoz slika u Flash
Comment[ca]=Una eina per exportar imatges a Flash
Comment[ca@valencia]=Una eina per exportar imatges a Flash
Comment[cs]=Nástroj pro export obrázků do Flashe
Comment[da]=Et værktøj til at eksportere billeder til Flash
Comment[de]=Ein Werkzeug, um Bilder zu Flash zu exportieren.
Comment[el]=Εργαλείο εξαγωγής εικόνων σε Flash
Comment[en_GB]=A tool to export images to Flash
Comment[es]=Herramienta para exportar imágenes para Flash
Comment[et]=Tööriist piltide eksportimiseks Flashi
Comment[eu]=Irudiak Flash-era esportatzeko tresna bat
Comment[fi]=Kuvien vienti Flash-tiedostoksi
Comment[fr]=Outil d'exportation d'images en Flash
Comment[ga]=Uirlis a easpórtálann íomhánna go Flash
Comment[gl]=Unha ferramenta para exportar imaxes a Flash
Comment[he]=כלי ליצוא תמונות לפלאש
Comment[hne]=फोटू ल फ्लेस मं निर्यात करे के एक औजार
Comment[hu]=Egy eszköz képek exportálásához Flash-be
Comment[is]=Verkfæri til að flytja myndir út í Flash
Comment[it]=Uno strumento per esportare immagini a Flash
Comment[ja]=画像を Flash にエクスポートするツール
Comment[km]=ឧបករណ៍​ត្រូវ​នាំរូបភាព​ចេញ​ទៅ Flash
Comment[lv]=Rīks attēlu eksportēšanai Flash formātā
Comment[nb]=Et verktøy for å eksportere bilder til Flash
Comment[nds]=En Warktüüch, mit dat sik Biller na't Flash-Formaat wanneln laat
Comment[nl]=Een hulpmiddel voor het exporteren van afbeeldingen naar Flash
Comment[pa]=ਚਿੱਤਰਾਂ ਨੂੰ ਫਲੈਸ਼ ਲਈ ਐਕਸਪੋਰਟ ਕਰਨ ਲਈ ਟੂਲ
Comment[pl]=Narzędzie do eksportu obrazów Flash
Comment[pt]=Uma ferramenta para exportar imagens para Flash
Comment[pt_BR]=Uma ferramenta para exportar imagens para Flash
Comment[ro]=O unealtă de exportat imagini în Flash
Comment[ru]=Инструмент для экспорта изображений во Flash
Comment[sk]=Nástroj na export obrázkov do Flash
Comment[sl]=Orodje za izvoz slik v Flash
Comment[sq]=Një mjet për të eksportuar imazhet në Flash
Comment[sv]=Ett verktyg för att exportera bilder till Flash
Comment[th]=เครื่องมือส่งออกภาพต่าง ๆ เป็นแฟ้มสื่อประเภท Flash
Comment[tr]=Resimleri USB belleğe aktarmak için bir araç
Comment[uk]=Інструмент для експортування зображень до Flash
Comment[x-test]=xxA tool to export images to Flashxx
Comment[zh_CN]=一个将图像导出为 Flash 的工具
Comment[zh_TW]=匯出影像到 Flash 的工具
Type=Service
Icon=flash
ServiceTypes=KIPI/Plugin
X-KDE-Library=kipiplugin_flashexport
X-KIPI-PluginCategories=Export
X-KIPI-BinaryVersion=${KIPI_SO_VERSION}
author=Gilles Caulier, caulier dot gilles at gmail dot com

==> digikam-4.7.0.tar.bz2: digikam-4.7.0/extra/kipi-plugins/flashexport/kipiplugin_flashexport.desktop.cmake <==
[Desktop Entry]
UntranslatedGenericName=Flash Export
Name=Flash Export
Name[ast]=Esportar flash
Name[bg]=Изнасяне във Flash
Name[bs]=Flash izvoz
Name[ca]=Exportador a Flash
Name[ca@valencia]=Exportador a Flash
Name[cs]=Flash Export
Name[da]=Flash-eksport
Name[de]=Flash-Export
Name[el]=Εξαγωγή Flash
Name[en_GB]=Flash Export
Name[es]=Exportar a Flash
Name[et]=Flashi eksport
Name[eu]=Flash-era esportatzea
Name[fi]=Flash-vienti
Name[fr]=Exportation « Flash »
Name[ga]=Easpórtáil Flash
Name[gl]=Exportación a Flash
Name[hu]=Flash exportálás
Name[is]=Flash útflutningur
Name[it]=Esportazione a Flash
Name[ja]=Flash Export
Name[km]=កម្មវិធី​នាំចេញ Flash
Name[lt]=Flash eksportas
Name[lv]=Flash eksportētājs
Name[nb]=Flash-eksport
Name[nds]=Flash-Exporteren
Name[nl]=Flash-export
Name[pa]=ਫਲੈਸ਼ ਐਕਸਪੋਰਟ
Name[pl]=Eksport Flash
Name[pt]=Exportação para Flash
Name[pt_BR]=Exportar para Flash
Name[ro]=Export Flash
Name[ru]=Экспорт во Flash
Name[sk]=Flash export
Name[sl]=Izvoz v Flash
Name[sq]=Flash Export
Name[sv]=Export till Flash
Name[th]=ส่งออกเป็นแฟ้ม Flash
Name[tr]=Flash olarak Dışarı Aktar
Name[ug]=Flash Export
Name[uk]=Експорт у Flash
Name[x-test]=xxFlash Exportxx
Name[zh_CN]=Flash 导出
Name[zh_TW]=Flash 匯出
Comment=A tool to export images to Flash
Comment[ast]=Una ferramienta pa esportar imáxenes a Flash
Comment[bg]=Инструмент за изнасяне на изображения във Flash
Comment[bs]=Alat za izvoz slika u Flash
Comment[ca]=Una eina per exportar imatges a Flash
Comment[ca@valencia]=Una eina per exportar imatges a Flash
Comment[cs]=Nástroj pro export obrázků do Flashe
Comment[da]=Et værktøj til at eksportere billeder til Flash
Comment[de]=Ein Werkzeug, um Bilder zu Flash zu exportieren.
Comment[el]=Εργαλείο εξαγωγής εικόνων σε Flash
Comment[en_GB]=A tool to export images to Flash
Comment[es]=Herramienta para exportar imágenes para Flash
Comment[et]=Tööriist piltide eksportimiseks Flashi
Comment[eu]=Irudiak Flash-era esportatzeko tresna bat
Comment[fi]=Kuvien vienti Flash-tiedostoksi
Comment[fr]=Outil d'exportation d'images en Flash
Comment[ga]=Uirlis a easpórtálann íomhánna go Flash
Comment[gl]=Unha ferramenta para exportar imaxes a Flash
Comment[he]=כלי ליצוא תמונות לפלאש
Comment[hne]=फोटू ल फ्लेस मं निर्यात करे के एक औजार
Comment[hu]=Egy eszköz képek exportálásához Flash-be
Comment[is]=Verkfæri til að flytja myndir út í Flash
Comment[it]=Uno strumento per esportare immagini a Flash
Comment[ja]=画像を Flash にエクスポートするツール
Comment[km]=ឧបករណ៍​ត្រូវ​នាំរូបភាព​ចេញ​ទៅ Flash
Comment[lt]=Įrankis eksportuoti paveikslėlius į Flash
Comment[lv]=Rīks attēlu eksportēšanai Flash formātā
Comment[nb]=Et verktøy for å eksportere bilder til Flash
Comment[nds]=En Warktüüch, mit dat sik Biller na't Flash-Formaat wanneln laat
Comment[nl]=Een hulpmiddel voor het exporteren van afbeeldingen naar Flash
Comment[pa]=ਚਿੱਤਰਾਂ ਨੂੰ ਫਲੈਸ਼ ਲਈ ਐਕਸਪੋਰਟ ਕਰਨ ਲਈ ਟੂਲ
Comment[pl]=Narzędzie do eksportu obrazów Flash
Comment[pt]=Uma ferramenta para exportar imagens para Flash
Comment[pt_BR]=Ferramenta para exportar imagens para Flash
Comment[ro]=O unealtă de exportat imagini în Flash
Comment[ru]=Инструмент для экспорта изображений во Flash
Comment[sk]=Nástroj na export obrázkov do Flash
Comment[sl]=Orodje za izvoz slik v Flash
Comment[sq]=Një mjet për të eksportuar imazhet në Flash
Comment[sv]=Ett verktyg för att exportera bilder till Flash
Comment[th]=เครื่องมือส่งออกภาพต่าง ๆ เป็นแฟ้มสื่อประเภท Flash
Comment[tr]=Resimleri USB belleğe aktarmak için bir araç
Comment[uk]=Інструмент для експортування зображень до Flash
Comment[x-test]=xxA tool to export images to Flashxx
Comment[zh_CN]=一个将图像导出为 Flash 的工具
Comment[zh_TW]=匯出影像到 Flash 的工具
Type=Service
Icon=kipi-flash
ServiceTypes=KIPI/Plugin
X-KDE-Library=kipiplugin_flashexport
X-KIPI-PluginCategories=Export
X-KIPI-BinaryVersion=${KIPI_SO_VERSION}
author=Gilles Caulier, caulier dot gilles at gmail dot com
